<?php
// This is a SPIP language file  --  Ceci est un fichier langue de SPIP
// extrait automatiquement de https://trad.spip.net/tradlang_module/spip_?lang_cible=cpf_hat
// ** ne pas modifier le fichier **

return [

	// A
	'access_interface_graphique' => 'Tounen dèyé si lentèfas gwafik konple',
	'access_mode_texte' => 'Afiche lentèfas tèks senp',
	'admin_debug' => 'debug',
	'admin_modifier_article' => 'Chanje atik-la',
	'admin_modifier_auteur' => 'Chanje bagay pou lotè-a',
	'admin_modifier_breve' => 'Chanje ti-nouvèl la',
	'admin_modifier_mot' => 'Chanje mokle-a',
	'admin_modifier_rubrique' => 'Chanje ribwik-la (pati-a nan sit sa-a)',
	'admin_recalculer' => 'Kalkil ankò paj-la',
	'afficher_trad' => 'afiche twadiksyon yo',
	'alerte_maj_impossible' => '<<b>Atansyon !</b> Larnouvèlman pou baz SQL sou @version@ se pa posib, petèt ka gen yon pwoblèm ek drwa pou chanje bazdone-a. Tanpri souple kontak lébèjè ou.', # MODIF
	'alerte_modif_info_concourante' => 'ATTENTION : Cette information a été modifié par ailleurs. La valeur actuelle est :', # MODIF
	'analyse_xml' => 'Analiz XML',
	'articles_recents' => 'Atik yo ki plis resan',
	'avis_archive_incorrect' => 'fichye achiv-a se pa fichye SPIP',
	'avis_archive_invalide' => 'fichye achiv-a se pa korèk',
	'avis_attention' => 'ATANSYON !',
	'avis_champ_incorrect_type_objet' => 'Kouman chan-a li ap rele, pou bagay-la, se pa korek @name@ pou lojè tip @type@',
	'avis_colonne_inexistante' => 'Kolòn nan @col@ pa egziste kounye-a',
	'avis_erreur' => 'Erè : tanpri gad isit anba',
	'avis_erreur_connexion' => 'Erè ak koneksyon',
	'avis_erreur_cookie' => 'pwoblèm èk gatomakro (kouki)',
	'avis_erreur_fonction_contexte' => 'Erè ak pwogwmasyon. Fok w pa rele fonksyon-nan andan kontèks-la.', # MODIF
	'avis_erreur_mysql' => 'Erè SQL', # MODIF
	'avis_erreur_sauvegarde' => 'Erè nan sovgad (@type@ @id_objet@) !',
	'avis_erreur_visiteur' => 'Pwoblèm pou antre nan lespas privé',

	// B
	'barre_a_accent_grave' => 'Mèt yon A aksan gwav majiskil',
	'barre_aide' => 'Tichemen tipogwafik yo y fé yon paj pli bèl',
	'barre_e_accent_aigu' => 'Mèt yon E aksan ègi majiskil',
	'barre_eo' => 'Mèt yon E nan O',
	'barre_eo_maj' => 'Mèt yon E nan lèt O majiskil',
	'barre_euro' => 'Mèt senbol €',
	'barre_gras' => 'Fé parèt ékri{{gra}}',
	'barre_guillemets' => 'Pou mèt « giymé fransé yo »',
	'barre_guillemets_simples' => 'Pou mèt giymé yo',
	'barre_intertitre' => 'Mèt bagay kon yon {{{lentètit}}}',
	'barre_italic' => 'Fé parèt ékri {italik}',
	'barre_lien' => 'Chanje pou yon [lyen ipetèks->http://...]',
	'barre_lien_input' => 'Tanpri souple enskri ladrès lyen ou (posib enskri yon ladrès wèb nan fòma http://www.monsite/com osnon senpman enskri nimewo atik-la nan sit sa-a.',
	'barre_note' => 'Chanje pou mèt yon [[Not enba la paj]]',
	'barre_quote' => '<quote>Rapòt yon mesaj</quote>',
	'bouton_changer' => 'Chanje',
	'bouton_chercher' => 'Chèche',
	'bouton_choisir' => 'Chwazi',
	'bouton_enregistrer' => 'Enskri',
	'bouton_radio_desactiver_messagerie_interne' => 'Rete kazmodekri',
	'bouton_radio_envoi_annonces' => 'Voye anons leditoyal ',
	'bouton_radio_non_envoi_annonces' => 'Rete voye anons yo',
	'bouton_radio_non_envoi_liste_nouveautes' => 'Rete voye yon lis nouvèlte yo',
	'bouton_recharger_page' => 'Chaje ankò paj-la',
	'bouton_telecharger' => 'Telechaje',
	'bouton_upload' => 'Telechaje', # MODIF
	'bouton_valider' => 'Konfime',

	// C
	'cal_apresmidi' => 'aprémidi',
	'cal_jour_entier' => 'jou konplé',
	'cal_matin' => 'maten',
	'cal_par_jour' => 'kalandrye pa jou',
	'cal_par_mois' => 'kalandrye pa mwa',
	'cal_par_semaine' => 'kalandrye pa semèn',
	'choix_couleur_interface' => 'koulè',
	'choix_interface' => 'pou chwazi lentefas',
	'confirm_changer_statut' => 'Atansyon. W te domann chanje lestati eleman nan. Eske w gen kontinye ?',
	'correcte' => 'korek',

	// D
	'date_aujourdhui' => 'jodiya',
	'date_avant_jc' => 'avan J.C.',
	'date_dans' => 'nan @delai@',
	'date_de_mois_1' => '@j@ @nommois@',
	'date_de_mois_10' => '@j@ @nommois@',
	'date_de_mois_11' => '@j@ @nommois@',
	'date_de_mois_12' => '@j@ @nommois@',
	'date_de_mois_2' => '@j@ @nommois@',
	'date_de_mois_3' => '@j@ @nommois@',
	'date_de_mois_4' => '@j@ @nommois@',
	'date_de_mois_5' => '@j@ @nommois@',
	'date_de_mois_6' => '@j@ @nommois@',
	'date_de_mois_7' => '@j@ @nommois@',
	'date_de_mois_8' => '@j@ @nommois@',
	'date_de_mois_9' => '@j@ @nommois@',
	'date_demain' => 'demen',
	'date_fmt_heures_minutes' => '@h@h@m@min',
	'date_fmt_jour' => '@nomjour@ @jour@',
	'date_fmt_jour_heure' => '@jour@ a @heure@',
	'date_fmt_jour_heure_debut_fin' => '@jour@ de @heure_debut@ a @heure_fin@',
	'date_fmt_jour_heure_debut_fin_abbr' => '@dtstart@@jour@ de @heure_debut@@dtabbr@ a @dtend@@heure_fin@@dtabbr@',
	'date_fmt_jour_mois' => '@jour@ @nommois@',
	'date_fmt_jour_mois_annee' => '@jour@ @nommois@ @annee@',
	'date_fmt_mois_annee' => '@nommois@ @annee@',
	'date_fmt_nomjour' => '@nomjour@ @date@',
	'date_fmt_nomjour_date' => 'nan jou ki te @nomjour@ @date@ -a',
	'date_fmt_periode' => 'Del @date_debut@ fins @date_fin@',
	'date_fmt_periode_abbr' => 'Del @dtart@@date_debut@@dtabbr@ fins @dtend@@date_fin@@dtabbr@',
	'date_heures' => 'èr (yo)',
	'date_hier' => 'yè',
	'date_il_y_a' => ' genyen @delai@',
	'date_jnum1' => '1e',
	'date_jnum10' => '10',
	'date_jnum11' => '11',
	'date_jnum12' => '12',
	'date_jnum13' => '13',
	'date_jnum14' => '14',
	'date_jnum15' => '15',
	'date_jnum16' => '16',
	'date_jnum17' => '17',
	'date_jnum18' => '18',
	'date_jnum19' => '19',
	'date_jnum2' => '2',
	'date_jnum20' => '20',
	'date_jnum21' => '21',
	'date_jnum22' => '22',
	'date_jnum23' => '23',
	'date_jnum24' => '24',
	'date_jnum25' => '25',
	'date_jnum26' => '26',
	'date_jnum27' => '27',
	'date_jnum28' => '28',
	'date_jnum29' => '29',
	'date_jnum3' => '3',
	'date_jnum30' => '30',
	'date_jnum31' => '31',
	'date_jnum4' => '4',
	'date_jnum5' => '5',
	'date_jnum6' => '6',
	'date_jnum7' => '7',
	'date_jnum8' => '8',
	'date_jnum9' => '9',
	'date_jour_1' => 'dimanch',
	'date_jour_1_abbr' => 'dim.',
	'date_jour_1_initiale' => 'd.',
	'date_jour_2' => 'lendi',
	'date_jour_2_abbr' => 'len.',
	'date_jour_2_initiale' => 'l.',
	'date_jour_3' => 'madi',
	'date_jour_3_abbr' => 'mad.',
	'date_jour_3_initiale' => 'm.',
	'date_jour_4' => 'mèkredi',
	'date_jour_4_abbr' => 'mek.',
	'date_jour_4_initiale' => 'm.',
	'date_jour_5' => 'jedi',
	'date_jour_5_abbr' => 'jed.',
	'date_jour_5_initiale' => 'j.',
	'date_jour_6' => 'vandredi',
	'date_jour_6_abbr' => 'van.',
	'date_jour_6_initiale' => 'v.',
	'date_jour_7' => 'sanmdi',
	'date_jour_7_abbr' => 'sam.',
	'date_jour_7_initiale' => 's.',
	'date_jours' => 'jou yo',
	'date_minutes' => 'minit yo',
	'date_mois' => 'mwa ',
	'date_mois_1' => 'janvye',
	'date_mois_10' => 'oktòb ',
	'date_mois_11' => 'novanm',
	'date_mois_12' => 'Desanm ',
	'date_mois_2' => 'fevriye',
	'date_mois_3' => 'mas',
	'date_mois_4' => 'avril',
	'date_mois_5' => 'me',
	'date_mois_6' => 'jen',
	'date_mois_7' => 'jiyè ',
	'date_mois_8' => 'out',
	'date_mois_9' => 'septanm',
	'date_saison_1' => 'ivè',
	'date_saison_2' => ' prentan',
	'date_saison_3' => 'lété',
	'date_saison_4' => 'lotòn',
	'date_semaines' => 'semèn yo',
	'dirs_commencer' => 'pou koumanse vreman lenstalasyon',
	'dirs_preliminaire' => 'Dabò : <b> ann swen drwa aksè</b>',
	'dirs_probleme_droits' => 'Pwoblèm ak drwa laksè',
	'dirs_repertoires_absents' => '<p><b>Oken répertwa sa-yo te fin rannkont :</b></p><ul>@bad_dirs@</ul>
  <p>  Petèt yon pwoblèm ek majiskil ousinon miniskil ki pa bon.
  Gad yo ap mache kom kisa ap parèt isit anlè
 ; sinon, fòk w rele yon lòt fwa tout repertwar sa-yo nan ou logisyèl FTP pou korij erè-a.</p>
  <p>Kan lafè ke fini, w ke kapab',
	'dirs_repertoires_suivants' => '<b>Pa posib ekri sou repètwa sa-yo : <ul>@bad_dirs@.</ul> </b>
  <p>Pou swen bagay-la, ann itilize logisyèl FTP ou pou don drwa laksé chak
 repètwa. Guid lenstalasyon ap di kouman w ke kapab fè bagay-la.
  </p><p>Kan w ke fini w ke kapab</p>', # MODIF
	'double_occurrence' => 'Double occurrence', # MODIF

	// E
	'envoi_via_le_site' => 'Voye ek sit-la',

	// F
	'fichier_introuvable' => 'Oken fisyé @fichier@ konsa', # MODIF
	'form_deja_inscrit' => 'W se deja enskri.',
	'form_email_non_valide' => 'Ladrès limèl ou se pa bon.',
	'form_forum_access_refuse' => 'W pli ap gen lakse sou sit-la.',
	'form_forum_bonjour' => 'Bonjou @nom@,,',
	'form_forum_email_deja_enregistre' => 'Adrès limèl-a deja enskri, w pé itiliz  modpas òdinè ou.',
	'form_forum_identifiant_mail' => 'Nouvo lidantifyan ou sé voye andan bwatlimèl ou. ',
	'form_forum_identifiants' => 'Idantifyan pèsonèl yo',
	'form_forum_indiquer_nom_email' => 'Enskri kouman w rele ak ladrès limèl ou Lidantifyan pèsonèl ou ke vini aprè vitman andan bwatlimèl ou.',
	'form_forum_login' => 'nonkod :',
	'form_forum_message_auto' => '(mesaj-la se yon mesaj otomatik)',
	'form_forum_pass' => 'modpas :',
	'form_forum_probleme_mail' => 'Pwoblèm pou limèl : lidantifyan pa posib anvway w.',
	'form_forum_voici1' => 'Lidantifyan y permé w soutni lavi
 sit-la "@nom_site_spip@" (@adresse_site@) :', # MODIF
	'form_forum_voici2' => 'Lidantifyan ou pou pwopoze atik yo sou
sit "@nom_site_spip@" (@adresse_login@) :', # MODIF
	'form_indiquer_email' => 'Mèsi enskri ladrès limèl ou.',
	'form_indiquer_nom' => 'Mèsi enskri kouman w rele',
	'form_indiquer_nom_site' => 'Mèsi enskri kouman sit ou-a li rele',
	'form_pet_deja_enregistre' => 'Sit-la se deja enskri',
	'form_pet_signature_pasprise' => 'Siyati ou se pa aksepte.',
	'form_prop_confirmer_envoi' => 'Konfime w vle voye i',
	'form_prop_description' => 'Dekrisyon/komantè',
	'form_prop_enregistre' => 'Pwopozisyon ou se kounye-a  ap enskri, li ke parèt apre yon komandè te konfime ali. ', # MODIF
	'form_prop_envoyer' => 'Voye yon mesaj',
	'form_prop_indiquer_email' => 'Mési enskri yon ladrès limèl ka mache',
	'form_prop_indiquer_nom_site' => 'Mèsi enskri kouman sit ou rele',
	'form_prop_indiquer_sujet' => 'Mèsi ékri yon sijé',
	'form_prop_message_envoye' => 'Mesaj te fin voye',
	'form_prop_non_enregistre' => 'Pwopozisyon ou te pa rojistré',
	'form_prop_sujet' => 'Sije',
	'form_prop_url_site' => 'Ladrès (URL) sitwèb', # MODIF
	'forum_non_inscrit' => 'W ap pa enskri ankò, oubyen ladrès osinon modpas ou se pa korèk.',
	'forum_par_auteur' => 'se @auteur@ te ekri',
	'forum_titre_erreur' => 'Erè ...',

	// I
	'ical_texte_rss_articles' => 'Fichyé «backend» pou tout atik yo, w ke rannkont sou ladrès la :',
	'ical_texte_rss_articles2' => 'W kap gen ositou fichye yo «backend» la pou tout atik yo nan chak ribrik sit la:',
	'ical_texte_rss_breves' => 'Plis gen yon fichye ka kontni tout tinouvèl yo pou sit la. W kap gen sèlman tinouvèl yo yon ribrik prési si w domann yon niméwo ribrik la sèlman. ',
	'icone_a_suivre' => 'Akèy',
	'icone_admin_site' => 'Kolonaj sit la',
	'icone_agenda' => 'Ajenda',
	'icone_aide_ligne' => 'Bourad',
	'icone_articles' => 'Atik yo',
	'icone_auteurs' => 'Lotè yo',
	'icone_brouteur' => 'Gad tout sit vitman',
	'icone_configuration_site' => 'Konfigire sit',
	'icone_configurer_site' => 'Konfigir sit ou',
	'icone_creer_nouvel_auteur' => 'Kreye yon nouvo lotè',
	'icone_creer_rubrique' => 'Kreye yon ribrik',
	'icone_creer_sous_rubrique' => 'Kreye yon sou-ribrik',
	'icone_deconnecter' => 'Rete koneksyon',
	'icone_discussions' => 'Kozman yo',
	'icone_doc_rubrique' => 'Dokiman yo nan ribrik yo',
	'icone_ecrire_article' => 'Ekri yon nouvo atik',
	'icone_edition_site' => 'Ledisyon',
	'icone_gestion_langues' => 'Okipe plizyè lang',
	'icone_informations_personnelles' => 'Ransèyman pèsonèl',
	'icone_interface_complet' => 'Entèfas konplé',
	'icone_interface_simple' => 'Entèfas senp',
	'icone_maintenance_site' => 'Swen pou sit la',
	'icone_messagerie_personnelle' => 'Kazmodékri',
	'icone_repartition_debut' => 'Afiche repatisyon depi koumansman',
	'icone_rubriques' => 'Ribrik yo',
	'icone_sauver_site' => 'Sov sit la',
	'icone_site_entier' => 'Tout sit sa mèm',
	'icone_sites_references' => 'Sit referansé yo',
	'icone_statistiques' => 'Rezilta estatistik sit la',
	'icone_suivi_activite' => 'Gad lavi sit la',
	'icone_suivi_actualite' => 'Evolisyon sit la',
	'icone_suivi_pettions' => 'Swiv/ okipe tout petisyon  ',
	'icone_suivi_revisions' => 'Chanjman nan atik yo',
	'icone_supprimer_document' => 'Kraze dokiman nan',
	'icone_supprimer_image' => 'Kraze imaj la',
	'icone_tous_articles' => 'Tout atik ou',
	'icone_tous_auteur' => 'Tout lotè yo',
	'icone_visiter_site' => 'Fè yon vire', # MODIF
	'icone_voir_en_ligne' => 'Gad an liy',
	'img_indisponible' => 'imaj-la se pa disponib',
	'impossible' => 'enposib',
	'info_a_suivre' => 'AKEY »',
	'info_acces_interdit' => 'Aksè entèdi',
	'info_acces_refuse' => 'Aksè refize',
	'info_action' => 'Aksyon: @action@',
	'info_administrer_rubriques' => 'W kapab jère ribrik-la ek souribrik yo',
	'info_adresse_non_indiquee' => 'W te pa done oken ladrès pou eseye !',
	'info_aide' => 'ED :',
	'info_ajouter_mot' => 'Ajoute mokle-a',
	'info_annonce' => 'ANNONS',
	'info_annonces_generales' => 'Annons pou toutmoun :',
	'info_article_propose' => 'Atik ki pwopoze ',
	'info_article_publie' => 'Atik ki pibliyé',
	'info_article_redaction' => 'Atik ki ap ekri ankò',
	'info_article_refuse' => 'Atik ki refize',
	'info_article_supprime' => 'Atik ki kraze',
	'info_articles' => 'Atik yo',
	'info_articles_a_valider' => 'Atik yo ki pou konfime',
	'info_articles_proposes' => 'Atik sa-yo se atik yo moun ki pwopozé',
	'info_auteurs_nombre' => 'lotè (yo) :',
	'info_authentification_ftp' => 'Lotantifikasyon (pa FTP).',
	'info_breves_2' => 'tinouvèl yo',
	'info_connexion_refusee' => 'Koneksyon te fin refize',
	'info_contact_developpeur' => 'Mèsi kotenouye yon devlopèr.', # MODIF
	'info_contenance' => 'Kisa ap kontni nan sit-la :',
	'info_contribution' => 'mesaj andan fowom', # MODIF
	'info_copyright' => '@spip@ se yon logisyèl lib ki done @lien_gpl@.',
	'info_copyright_doc' => 'Si w vle plis enfòmasyon, ann gad sit sa-a <a href="@spipnet@">http://www.spip.net/cpf</a>.', # MODIF
	'info_copyright_gpl' => 'nan lisans GPL',
	'info_cours_edition' => 'Tout atik yo w ka ekri ankò', # MODIF
	'info_creer_repertoire' => 'Kreye yon fichye ousinon yon répètwa sak i rele :',
	'info_creer_repertoire_2' => 'nan sou-repètwa <b>@repertoire@</b>, epi :', # MODIF
	'info_creer_vignette' => 'kreyasyon viyèt otomatik ',
	'info_deplier' => 'Etann',
	'info_descriptif_nombre' => 'dekrisyon(yo) :',
	'info_description' => 'Dekrisyon :',
	'info_description_2' => 'Dekrisyon :',
	'info_dimension' => 'Tay :',
	'info_ecire_message_prive' => 'Ekri yon mesaj prive',
	'info_email_invalide' => 'Adrès limèl se pa bon.',
	'info_en_cours_validation' => 'Atik sa-yo se tout atik w yo ki ap ekri ankò',
	'info_en_ligne' => 'Moun ki ap an liy :',
	'info_envoyer_message_prive' => 'Voye yon mesaj prive pou lotè-a',
	'info_erreur_requete' => 'Erè nan rekèt :',
	'info_erreur_squelette2' => 'Oken leskelèt <b>@fichier@</b> se pa disponib...',
	'info_erreur_systeme' => 'Erè sistèm (errno @errsys@)',
	'info_erreur_systeme2' => 'Diskédir se petèt plen osnon bazdoné gen domaj<br />
<span style="color:red;">Esey w<a href=\'@script@\'>aranje baz-la</a>, osnon kontak lébèjè ou.</span>', # MODIF
	'info_fini' => 'W gen fin fini !',
	'info_format_image' => 'Kèk sòt imaj SPIP kapab itilize pou kreye vinyèt : @gd_formats@.',
	'info_format_non_defini' => 'fòma ki pa defini',
	'info_grand_ecran' => 'Gran lékran',
	'info_image_aide' => 'ED',
	'info_image_process_titre' => 'Kouman fè pou kreye kèk vinyèt',
	'info_impossible_lire_page' => '<b>Erè !</b> Fè lekti paj <tt><html>@test_proxy@</html></tt> pa proksi ou-a se pa posib  <tt>', # MODIF
	'info_installation_systeme_publication' => 'Enstalasyon sistèm de piblikasyon...',
	'info_installer_documents' => 'W kap enstalé otomatikman tout dokiman yo ki kontni nan dosyé-a @upload@.', # MODIF
	'info_installer_ftp' => 'Tankou komandè, w kap enstalé(pa FTP)kèk fichyé nn dosyé-a @upload@ pou aprè w kap chwazi yo isit-la direkman.', # MODIF
	'info_installer_images' => 'W kapab enstale kèk imaj nan fòma sa-yo JPEG, GIF ak PNG.',
	'info_installer_images_dossier' => 'Enstal imaj nan dosye @upload@ pou w ke kapab swazi yo isit aprè.', # MODIF
	'info_interface_complete' => 'entèfas konplé',
	'info_interface_simple' => 'Entèfas senp',
	'info_joindre_document_article' => 'W kap jwenn sou atik-la tout dokiman nan tip',
	'info_joindre_document_rubrique' => 'Nan ribrik-la, w kap ajoute tout dokiman nan tip',
	'info_joindre_documents_article' => 'W kap jwenn nan atik ou-a, tout dokiman nan tip :',
	'info_l_article' => 'atik sa-a',
	'info_la_breve' => 'tinouvèl-la',
	'info_la_rubrique' => 'ribrik la',
	'info_langue_principale' => 'Lalang prensipal nan sit-la',
	'info_largeur_vignette' => '@largeur_vignette@ × @hauteur_vignette@ piksel yo',
	'info_les_auteurs_1' => 'pa @les_auteurs@',
	'info_logo_format_interdit' => 'W selman kapab itilize yon logo nan fòma @formats@.',
	'info_logo_max_poids' => 'Fok logo yo se mwen @maxi@ (fichye sa-a se @actuel@).',
	'info_mail_fournisseur' => 'w@fournisseur.com',
	'info_message_2' => 'MESAJ',
	'info_message_supprime' => 'MESAJ KRAZE',
	'info_mise_en_ligne' => 'Ladat piblikasyon :',
	'info_modification_parametres_securite' => 'chanjman sou paramèt pou sekirite',
	'info_mois_courant' => 'Nan tan mwa-a :',
	'info_mot_cle_ajoute' => 'Mokle-a te fin ajoute sou',
	'info_multi_herit' => 'Lalang ka parèt otomatikman',
	'info_multi_langues_soulignees' => 'Tout <u>lang souliyé sa-yo</u> ap gen yon tradiksyon tout tèks sa-yo nan lentèfas. Si w chwazi lang sa-yo, genyen plen éléman sou sit piblik (dat, fòmulè)ki tradwi otomatikman. Pou tout lang ki pa souliyé an,  tout éléman sa-yo ke parèt nan lang prensipal sit ou.', # MODIF
	'info_multilinguisme' => 'Miltilengwism',
	'info_nom_non_utilisateurs_connectes' => 'Kouman ou rele pap parèt nan lis zitilizatè an liy.', # MODIF
	'info_nom_utilisateurs_connectes' => 'Kouman w rele ap parèt nan lis zitilizatè  an liy.', # MODIF
	'info_nombre_en_ligne' => 'Moun se an liy :',
	'info_non_resultat' => 'gen pa oken rézilta pou "@cherche_mot@"',
	'info_non_utilisation_messagerie' => 'W p’ap itilize lakazmodékri andan sit-la.',
	'info_nouveau_message' => 'W GEN YON NOUVO MESAJ',
	'info_nouveaux_messages' => 'W GEN @total_messages@ NOUVO MESAJ YO',
	'info_numero_abbreviation' => 'N° ',
	'info_pense_bete' => 'RAPLE-W',
	'info_petit_ecran' => 'Piti lékran',
	'info_pixels' => 'piksèl yo',
	'info_plusieurs_mots_trouves' => 'Kèk mokle te fin sòti pou "@cherche_mot@":',
	'info_portfolio_automatique' => 'Livlimaj otomatik :',
	'info_premier_resultat' => '[@debut_limit@ premye rezilta sa-yo si  @total@]',
	'info_premier_resultat_sur' => '[@debut_limit@ premye rezilta sa-yo si @total@]',
	'info_propose_1' => '[@nom_site_spip@] ka pwopoze : @titre@',
	'info_propose_2' => 'Atik pwopoze pou parèt
---------------',
	'info_propose_3' => 'Atik "@titre@" pwopoze pou parèt.',
	'info_propose_4' => 'W se invite pou vini gad ali ek donn anou  komantè ou',
	'info_propose_5' => 'nan fowom anba. W trouv ali sou ladrès:',
	'info_publie_01' => 'Atik la i rele "@titre@" te konfime pa @connect_nom@.',
	'info_publie_1' => '[@nom_site_spip@] KA PIBLIYE : @titre@',
	'info_publie_2' => 'Atik se pibliye
--------------',
	'info_rechercher' => 'Chèche',
	'info_rechercher_02' => 'Chèche :',
	'info_remplacer_vignette' => 'Chanje vinyèt otomatik ek yon logo pèsonèl :',
	'info_sans_titre_2' => 'ki pa rele',
	'info_selectionner_fichier' => 'W kapab chwazi yon fichye nan dosyé @upload@', # MODIF
	'info_selectionner_fichier_2' => 'Chwazi yon fichye :',
	'info_supprimer_vignette' => 'kraze viyèt-la',
	'info_symbole_bleu' => 'Senbol <b>ble</b> ki endik <b>yon pansbèt</b>: yon mesaj ou pou izaj pèsonèl ou.', # MODIF
	'info_symbole_jaune' => 'Senbol <b>jon</b> ki endik <b>yon anons pou tout redaktè</b> : ki visib pout tout redaktè nan espas prive, ak ki komandè kapab chanje selman.', # MODIF
	'info_symbole_vert' => 'Senbol <b>vèr</b> ki endik <b> yon mesaj  voye ant zot zitilizatè</b> sit la.', # MODIF
	'info_telecharger_nouveau_logo' => 'Téléchaj yon nouvo logo :',
	'info_telecharger_ordinateur' => 'Telechaj sou lòdinatè ou :',
	'info_tous_resultats_enregistres' => '[tout rézilta yo ki enskri nan memwar ]',
	'info_tout_afficher' => 'Fè parèt tout',
	'info_travaux_texte' => 'Sit-la pòkò konfigiré...Tounyen isit pli tar.',
	'info_travaux_titre' => 'Sit ki se ankò yon chantye',
	'info_trop_resultat' => 'Tro rézilta pou "@cherche_mot@" ; Mèsi présiz chèche ou.',
	'info_utilisation_messagerie_interne' => 'W kapab itilize lakazmodekri andodan sit sa-a.',
	'info_valider_lien' => 'konfime lyen sa-a',
	'info_verifier_image' => ', mèsi gad imaj sa-yo ki chaje korèkman.',
	'info_vignette_defaut' => 'Viyèt otomatik',
	'info_vignette_personnalisee' => 'Viyèt pèsonèl',
	'info_visite' => 'vizit :',
	'info_vos_rendez_vous' => 'W ke rannkont',
	'infos_vos_pense_bete' => 'Mesaj yo pou w raple-w', # MODIF

	// L
	'lien_afficher_icones_seuls' => 'Afiche ikòn yo sèlman',
	'lien_afficher_texte_icones' => 'Afiche ikòn ak tèks',
	'lien_afficher_texte_seul' => 'Fè parèt kisa se tèks sèlman',
	'lien_liberer' => 'mawonn',
	'lien_liberer_tous' => 'Mawonn tout atik sa-yo', # MODIF
	'lien_nouvea_pense_bete' => 'NOUVO RAPLE-W',
	'lien_nouveau_message' => 'NOUVO MESAJ',
	'lien_nouvelle_annonce' => 'YON NOUVEL ANNONS',
	'lien_petitions' => 'PETISYON',
	'lien_popularite' => 'popilèrité : @popularite@%',
	'lien_racine_site' => 'RASIN SIT-LA',
	'lien_reessayer' => 'eseye ankò yon lòt fwa',
	'lien_repondre_message' => 'Reponn sou sijè sa',
	'lien_supprimer' => 'kraze',
	'lien_tout_afficher' => 'Fè parèt tout',
	'lien_visite_site' => 'vizite sit sa-a',
	'lien_visites' => '@visites@ vizite yo',
	'lien_voir_auteur' => 'Gad lotè-a',
	'login_acces_prive' => 'akse nan espas prive',
	'login_autre_identifiant' => 'konèk w sou sit-la ek yon lòt idantifyan',
	'login_cookie_accepte' => 'Mèsi règ navigatè ou po li asèpt (pou sit la omwen)',
	'login_cookie_oblige' => 'Pou w genyen idantifyé nan manyen sir sou sit-la, fòk w asèpte gatomakro.',
	'login_deconnexion_ok' => 'Koneksyon se fini.',
	'login_erreur_pass' => 'Erè ak modpas-la.',
	'login_espace_prive' => 'espas privé',
	'login_identifiant_inconnu' => 'Lidantifyan-nan « @login@ » li se pa rokoni.',
	'login_login' => 'Nonnkod :',
	'login_login2' => 'Nonnkod (idantifyan pou koneksyon sou sit-la) :', # MODIF
	'login_login_pass_incorrect' => '(Kouman w rele osnon modpas ou se pa korèk.)',
	'login_motpasseoublie' => 'modpas ki oubliyé ?',
	'login_non_securise' => 'Tansyon; Fòmilè sa-a se pa sekirize. Si w vle pa
    modpas ou ke vole sou rezo, mèsi aktive Javascript
  nan navigatè ek',
	'login_nouvelle_tentative' => 'Ankò yon lòt esey',
	'login_par_ici' => 'W se enskri... pa isit la...',
	'login_pass2' => 'Modpas :',
	'login_preferez_refuser' => '<b>Si w vlé refize tout gatomakro </b>, gen yon lòt métòd pou konèkt a w (yon ki   gen pa pli gran sékirité) :',
	'login_recharger' => 'Chaj ankò paj-la',
	'login_rester_identifie' => 'Gad lidantifikasyon pou plizyè jou', # MODIF
	'login_retour_public' => 'Tounyen sou sit piblik',
	'login_retour_site' => 'Tounyen sou sit piblik',
	'login_retoursitepublic' => 'tounyen dèyè sou sit piblik',
	'login_sinscrire' => 'enskri w', # MODIF
	'login_test_navigateur' => 'test navigatè/rekoneksyon',
	'login_verifiez_navigateur' => '(Gad pou si navigatè ou li te pa raple modpas ou...)',

	// M
	'masquer_trad' => 'kache tradiksyon yo',
	'module_fichiers_langues' => 'Fichye-lang yo',

	// N
	'navigateur_pas_redirige' => 'Si navigatè ou se pa tounyen taptap sou yon lòt ladrès web, mèsi klik isit pou kontinye.',

	// O
	'onglet_affacer_base' => 'Kraze labaz',
	'onglet_auteur' => 'Lotè',
	'onglet_contenu_site' => 'Kisa sit-la ka kontni',
	'onglet_evolution_visite_mod' => 'Évolisyon',
	'onglet_fonctions_avances' => 'Tout fonksyon pwési ',
	'onglet_informations_personnelles' => 'Enfòmasyon pèsonèl',
	'onglet_interactivite' => 'Entèwaktivite',
	'onglet_messagerie' => 'Kazmodékri',
	'onglet_repartition_rubrique' => 'Repatisyon ant ribrik',
	'onglet_save_restaur_base' => 'Sòvgad/aranje labaz',
	'onglet_vider_cache' => 'Vide kach-la',

	// P
	'pass_choix_pass' => 'Mèsi chwazi nouvo modpas ou :',
	'pass_erreur' => 'Erè',
	'pass_erreur_acces_refuse' => '<b>Erè :</b> w gen pa pli oken aksé sou sit-la.',
	'pass_erreur_code_inconnu' => '<b>Erè :</b> kod-la ap’pa koresponn oken vizitè ki genyen aksé sou sit-la.', # MODIF
	'pass_erreur_non_enregistre' => '<b>Erè :</b> ladrès <tt>@email_oubli@</tt> ap pa enskri sou sit-la.',
	'pass_erreur_non_valide' => '<b>Erè :</b> limèl sa-a <tt>@email_oubli@</tt> ki pa mache !',
	'pass_erreur_probleme_technique' => '<b>Erè :</b> akoz yon pwoblèm teknik, se pa posib voye limèl sa-a.',
	'pass_espace_prive_bla' => 'Espas prive sit-la se ouvè pou tout vizitè
  ki enskri dabò. Kan w ap enskri w, w ke kapab,
  fè lekti tout atik ki ankò pou ekri ek pwopoze atik ou mem,
  osnon mem soutni nan tout fowom sit sa-a .', # MODIF
	'pass_forum_bla' => 'W ap domann soutni nan yon fowom ki rézève
  pou vizitè ki deja enskri.', # MODIF
	'pass_indiquez_cidessous' => 'Endik isit anba ladrès limèl w ap enskri w dabò.
W
   ke genyen yon limel ki di w kouman w ke kapab rekipè laksé ou.
',
	'pass_mail_passcookie' => '(Tala se mesaj otomatik)
Pou w genyen ankò lakse ou sou sit-la
@nom_site_spip@ (@adresse_site@)

Mèsi fè yon viré sou ladrès la :

    @sendcookie@

W ke kapab alò enskri yon nouvo modpas
ak tounyen déyé konekte sou sit-la.

', # MODIF
	'pass_mot_oublie' => 'Modpas ki oubliye',
	'pass_nouveau_enregistre' => 'Nouvo modpas ou-a se enskri nan mémwar.',
	'pass_nouveau_pass' => 'Nouvo modpas',
	'pass_ok' => 'OK',
	'pass_oubli_mot' => 'Modpas ki oublye ',
	'pass_quitter_fenetre' => 'Lage finèt-la',
	'pass_rappel_login' => 'Raple : lidantifyan ou-a (nondkod) se « @login@ ».',
	'pass_recevoir_mail' => 'W ke genyen yon limèl ki di w kouman w kapab rekipè laksé ou sou sit sa-a.', # MODIF
	'pass_retour_public' => 'Tounyen déyè sou sit piblik',
	'pass_rien_a_faire_ici' => 'Genyen pa ryen pou fè isit.',
	'pass_vousinscrire' => 'Enskri w sou sit sa-a',
	'precedent' => 'déyè',
	'previsualisation' => 'Pou gade avan pibliye',
	'previsualiser' => 'Gade avan pibliyé',

	// S
	'squelette' => 'eskelet',
	'squelette_inclus_ligne' => 'eskelet enkli, liy',
	'squelette_ligne' => 'eskelet,liy',
	'stats_visites_et_popularite' => '@visites@ vizit yo ; kouman se popilè : @popularite@',
	'suivant' => 'swivan',

	// T
	'taille_ko' => '@taille@ ko',
	'taille_mo' => '@taille@ Mo',
	'taille_octets' => '@taille@ oktè',
	'taille_octets_bi' => '@taille@ oktè',
	'texte_actualite_site_1' => 'Kan w genyen abitid ek lentèfas, w ke kapab piyé sou «',
	'texte_actualite_site_2' => 'entèfas konplé',
	'texte_actualite_site_3' => '» pou genyen plis posibilite.',
	'texte_creation_automatique_vignette' => 'Kreyasyon otomatik tout viyèt pou gade avan pibliyé ap mache jodiya sou sit-la. Si w enstal ek fòmilè sa-a imaj yo nan fòma (sa-yo) @gd_formats@, yo ke vini ak yon viyèt ki tay pli gran se @taille_preview@ piksel.',
	'texte_documents_associes' => 'Dokiman swivan sa-yo se asosye ek atik-la,
    poutan yo genyen pa dirèkman parèt nan atik-la. Kiswa kouman paj ou rosanm sou sit piblik,
    yo ki parèt nan fòm dokiman jwen.',
	'texte_erreur_mise_niveau_base' => 'Ere ek bazdone pou mèt nan nivo.
  imaj <b>@fichier@</b>  sa-a ki pa rive (article @id_article@).
  Ekri référans-la, ek esey yon lot fwa
  aranje nivo, epi gade si imaj yo ki kapab parèt
  byen toujou nan atik yo.', # MODIF
	'texte_erreur_visiteur' => 'W t eseye antre nan lespas privé ak yon lidantifyan an ki pa rive pèmèt aksyon la.', # MODIF
	'texte_inc_auth_1' => 'Kouman w rele pou genyen idantifye w 
 <b>@auth_login@</b>, soman li pli/pa egsite nan bazdone. 
  Esey', # MODIF
	'texte_inc_auth_2' => 'konèk w ankò yon lot fwa',
	'texte_inc_auth_3' => ', aprè w pètèt lage épi
 rèt ek démar yon lot fwa navigatè ou.',
	'texte_inc_config' => 'Tout chanjman nan paj sa-yo genyen gran enflians si manyen sit-la ka mache.
 Lès azot bagay-la sou kote kounyen-a, si w genyen pòkò gran abitid ak manyen kouman SPIP mache.
<br /><br /><b> Ann
lès plitò jestyon paj sa-yo pou wèbmèt prensipal sou sit-la.</b>', # MODIF
	'texte_inc_meta_1' => 'Sistèm la ki genyen yon erè ak lékriti fichye <code>@fichier@</code>. Mèsi, w ki komandè sit-la,', # MODIF
	'texte_inc_meta_2' => 'gade tout drwa lékriti se korek',
	'texte_inc_meta_3' => 'nan répètwa <code>@repertoire@</code>.', # MODIF
	'texte_statut_en_cours_redaction' => 'ankò pou ekri',
	'texte_statut_poubelle' => 'nan bwat poubèl',
	'texte_statut_propose_evaluation' => 'pwopoze pou jijman',
	'texte_statut_publie' => 'pibliye an ly',
	'texte_statut_refuse' => 'refize',
	'titre_ajouter_mot_cle' => 'AJOUTE YON MOKLE :',
	'titre_cadre_raccourcis' => 'TICHEMEN YO :',
	'titre_changer_couleur_interface' => 'Chanje koulè lentèfas',
	'titre_image_admin_article' => 'W kapab jère atik-la',
	'titre_image_administrateur' => 'Komandè', # MODIF
	'titre_image_aide' => 'Ann genyen èd sou eleman nan',
	'titre_image_auteur_supprime' => 'Lotè te kraze',
	'titre_image_redacteur' => 'Redaktè ap gen pa aksè',
	'titre_image_redacteur_02' => 'Redaktè',
	'titre_image_visiteur' => 'Vizitè',
	'titre_joindre_document' => 'JWENN YON DOKIMAN',
	'titre_mots_cles' => 'MOKLE YO',
	'titre_probleme_technique' => 'Atansyon : yon pxoblèm teknik (sèrvèr SQL) fe entediksyon antre nan pati a nan sit sa a. Mési konprann.', # MODIF
	'titre_publier_document' => 'PIBLIYE YON DOKIMAN NAN PATI A NAN SIT SA A',
	'titre_statistiques' => 'Estatistik sit la',
	'titre_titre_document' => 'Kouman rele dokiman a :',
	'trad_reference' => '(atik pou referans)', # MODIF

	// Z
	'zbug_balise_b_aval' => ' : baliz B anba',
	'zbug_balise_inexistante' => 'erreur @from@: la balise #@balise@ n’existe pas', # MODIF
	'zbug_boucle' => 'boukle',
	'zbug_boucle_recursive_undef' => 'boukle rekisiv ki pa défini', # MODIF
	'zbug_champ_hors_boucle' => 'Chan @champ@ ki pa nan boukle',
	'zbug_champ_hors_motif' => 'Chan @champ@ ki pa nan boukle-motif @motif@', # MODIF
	'zbug_code' => 'kod',
	'zbug_critere_inconnu' => 'kritè sa-a se pa koni @critere@', # MODIF
	'zbug_distant_interdit' => 'déò entèdi', # MODIF
	'zbug_doublon_table_sans_cle_primaire' => 'doublons sur une table sans clef primaire atomique', # MODIF
	'zbug_doublon_table_sans_index' => 'doublons sur une table sans index', # MODIF
	'zbug_erreur_boucle_double' => 'BOUCLE@id@: définisyon doub', # MODIF
	'zbug_erreur_boucle_fermant' => 'BOUCLE@id@: tag pou fème ap pa egsiste ', # MODIF
	'zbug_erreur_boucle_syntaxe' => 'Sintaks boukl pa korèk', # MODIF
	'zbug_erreur_execution_page' => 'erè nan leksékisyon paj la', # MODIF
	'zbug_erreur_filtre' => 'Erè: fil <b>« @filtre@ »</b> se pa defini ', # MODIF
	'zbug_erreur_meme_parent' => '{meme_parent} ki pa mache ak (FORUMS) oubyen (RUBRIQUES)', # MODIF
	'zbug_erreur_squelette' => 'Erè nan lèskelèt',
	'zbug_info_erreur_squelette' => 'Erè sou sit-la',
	'zbug_inversion_ordre_inexistant' => 'yon ord ki pa egziste genyen lanvè', # MODIF
	'zbug_pagination_sans_critere' => '#PAGINATION sans critère {pagination} ou employé dans une boucle recursive', # MODIF
	'zbug_parametres_inclus_incorrects' => 'Paramèt pou enklizyon se pa korek', # MODIF
	'zbug_resultat' => 'rézilta',
	'zbug_serveur_indefini' => 'sèvè SQL ki pa defini', # MODIF
	'zbug_table_inconnue' => 'Tab SQL « @table@ » se pa koni',
];
